#!/bin/bash
# Copyright (c) 2012 Cloudera, Inc. All rights reserved.

# Time marker for both stderr and stdout
date; date 1>&2

cloudera_config=`dirname $0`
cloudera_config=`cd "$cloudera_config/../common"; pwd`
. ${cloudera_config}/cloudera-config.sh

# Load the parcel environment
source_parcel_environment

echo "using $CDH_VERSION as CDH_VERSION"
echo "using $SERVICE_TYPE as SERVICE_TYPE"
echo "using $CONF_DIR as CONF_DIR"
echo "using $DIRECTORY_NAME as DIRECTORY_NAME"
echo "using $ETC_DIR_NAME as ETC_DIR_NAME"
echo "using $ALT_NAME as ALT_NAME"
echo "using $PRIORITY as PRIORITY"

# debug
set -x
set -e

CONF=conf
LINK="$ETC_DIR_NAME/$CONF"
UPDATE_ALTERNATIVES=/usr/sbin/update-alternatives

ZIP_FILE="$1"
SRC_NAME="$DIRECTORY_NAME"
DEST_NAME="$2"
DEST_PATH="$ETC_DIR_NAME/$DEST_NAME"

# local replacement of substitution variables.
perl -pi -e "s#{{CDH_MAPRED_HOME}}#$CDH_MR2_HOME#g" $CONF_DIR/$SRC_NAME/*
perl -pi -e "s#{{CDH_HADOOP_HOME}}#$CDH_HADOOP_HOME#g" $CONF_DIR/$SRC_NAME/*
# replacement for HBASE_CONF_DIR
perl -pi -e "s#{{HBASE_CONF_DIR}}#$LINK#g" $CONF_DIR/$SRC_NAME/*

# If the conf dir's parent doesn't exist, we have to create it
# as alternatives won't do it for us.
if [ ! -e "$ETC_DIR_NAME" ]; then
  mkdir -p "$ETC_DIR_NAME"
fi

cd "$ETC_DIR_NAME"

# Special case handling for taskcontroller.cfg and container-executor.cfg.
# These special files *must* exist in a specific location that typically
# collides with the expected client config location. As it is a file generated
# during role startup, we can't generate it as part of the client config, so 
# we need to preserve it if it currently exists.
for SPECIAL_FILE in $CONF/{taskcontroller,container-executor}.cfg
do
  if [ -e $SPECIAL_FILE ]; then
    cp -a $SPECIAL_FILE "$CONF_DIR/$SRC_NAME"
  fi
done

# If the conf dir isn't a symlink, then move it out of the way
# so alternatives can work. Specifically for hbase...
# See CDH-2980
if [ -d $CONF -a ! -L $CONF ]; then
  # This should be trivial with mv but Redhat didn't fix
  # it to work until 2011 in RHEL5.7 (original patch from 2006)
  # mv --backup=numbered $CONF $CONF.beforeClouderaManager
  TMP_NAME=`mktemp -d $CONF.beforeClouderaManager.XXXXXX`
  for file in `find $CONF -mindepth 1`; do
    mv "$file" $TMP_NAME/
  done
  rmdir $CONF
fi
rm -rf "$DEST_NAME"
cp -a "$CONF_DIR/$SRC_NAME" "$DEST_NAME"
chmod -R ugo+r "$DEST_NAME"

# CDH3 Hive expects the hive-default.xml to be in the conf dir
if [[ "$SERVICE_TYPE" == HIVE ]]; then
  copy_hive_default "$DEST_PATH"
fi
$UPDATE_ALTERNATIVES --install "$LINK" "$ALT_NAME" "$DEST_PATH" $PRIORITY
$UPDATE_ALTERNATIVES --auto "$ALT_NAME"

